@@ -4,14 +4,10 @@
 
 package Date::Language::TigrinyaEritrean;
 
-use strict;
-use warnings;
-use base 'Date::Language';
-
-our $VERSION = '2.34_01'; # TRIAL VERSION: generated
-# ABSTRACT: TigrinyaEritrean localization for Date::Format
-
-our (@DoW, @DoWs, @MoY, @MoYs, @AMPM, @Dsuf, %MoY, %DoW);
+use Date::Language ();
+use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW $VERSION);
+@ISA = qw(Date::Language);
+$VERSION = "1.00";
 
 if ( $] >= 5.006 ) {
 @DoW = (
@@ -80,7 +76,10 @@ else {
 @Dsuf = ("ይ" x 31);
 }
 
-Date::Language::_build_lookups();
+@MoY{@MoY}  = (0 .. scalar(@MoY));
+@MoY{@MoYs} = (0 .. scalar(@MoYs));
+@DoW{@DoW}  = (0 .. scalar(@DoW));
+@DoW{@DoWs} = (0 .. scalar(@DoWs));
 
 # Formatting routines
 
@@ -92,30 +91,3 @@ sub format_h { $MoYs[$_[0]->[4]] }
 sub format_p { $_[0]->[2] >= 12 ?  $AMPM[1] : $AMPM[0] }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Date::Language::TigrinyaEritrean - TigrinyaEritrean localization for Date::Format
-
-=head1 VERSION
-
-version 2.34_01
-
-=head1 AUTHOR
-
-Graham <gbarr@pobox.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by Graham Barr.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
